@@ -316,7 +316,7 @@ static SPDVoice **output_get_voices(OutputModule * module)
 			break;
 		else if (lines[i][3] == '-') {
 			atoms = g_strsplit(&lines[i][4], "\t", 0);
-			// Name, language, dialect
+			// Name, language, variant
 			if ((atoms[0] == NULL) || (atoms[1] == NULL)
 			    || (atoms[2] == NULL)) {
 				errors = TRUE;
@@ -475,7 +475,9 @@ int output_send_audio_settings(OutputModule * output)
 	ADD_SET_STR(audio_oss_device);
 	ADD_SET_STR(audio_alsa_device);
 	ADD_SET_STR(audio_nas_server);
-	ADD_SET_STR(audio_pulse_server);
+	// TODO: restore AudioPulseServer option
+	//ADD_SET_STR(audio_pulse_server);
+	ADD_SET_STR(audio_pulse_device);
 	ADD_SET_INT(audio_pulse_min_length);
 
 	SEND_CMD_N("AUDIO");
@@ -540,9 +542,8 @@ int output_send_debug(OutputModule * output, int flag, char *log_path)
 	OL_RET(0);
 }
 
-int output_speak(TSpeechDMessage * msg)
+int output_speak(TSpeechDMessage * msg, OutputModule *output)
 {
-	OutputModule *output;
 	int err;
 	int ret;
 
@@ -551,13 +552,6 @@ int output_speak(TSpeechDMessage * msg)
 
 	output_lock();
 
-	/* Determine which output module should be used */
-	output = get_output_module(msg);
-	if (output == NULL) {
-		MSG(3, "Output module doesn't work...");
-		OL_RET(-1)
-	}
-
 	msg->buf = escape_dot(msg->buf);
 	msg->bytes = -1;
 
