@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * $Id: speechd.h,v 1.64 2008-06-27 12:29:07 hanke Exp $
  */
@@ -45,6 +43,7 @@
 #include <pthread.h>
 
 #include <glib.h>
+#include <glib-unix.h>
 
 #include <semaphore.h>
 #include <sys/ipc.h>
@@ -75,11 +74,13 @@ union semun {
 typedef struct {
 	unsigned int uid;	/* Unique ID of the client */
 	int fd;			/* File descriptor the client is on. */
+	guint fd_source;	/* Used to store the GSource ID for watching fd activity in the main loop */
 	int active;		/* Is this client still active on socket or gone? */
 	int paused;		/* Internal flag, 1 for paused client or 0 for normal. */
 	int paused_while_speaking;
 	SPDMessageType type;	/* Type of the message (1=text, 2=icon, 3=char, 4=key) */
 	SPDDataMode ssml_mode;	/* SSML mode on (1)/off (0) */
+	gboolean symbols_preprocessing; /* whether to transform symbols/punctuation in the input */
 	SPDPriority priority;	/* Priority between 1 and 5 (1 - highest, 5 - lowest) */
 	SPDMsgSettings msg_settings;
 	char *client_name;	/* Name of the client. */
@@ -98,6 +99,7 @@ typedef struct {
 	char *audio_alsa_device;
 	char *audio_nas_server;
 	char *audio_pulse_server;
+	char *audio_pulse_device;
 	int audio_pulse_min_length;
 	int log_level;
 
@@ -122,7 +124,7 @@ typedef enum {
 	SPD_MODE_SINGLE		/*  */
 } TSpeechDMode;
 
-TSpeechDMode spd_mode;
+extern TSpeechDMode spd_mode;
 
 /*  TSpeechDQueue is a queue for messages. */
 typedef struct {
@@ -147,7 +149,7 @@ typedef struct {
 #include "alloc.h"
 #include "speaking.h"
 
-struct {
+extern struct SpeechdOptions {
 	char *communication_method;
 	int communication_method_set;
 	char *socket_path;
@@ -160,63 +162,59 @@ struct {
 	char *conf_dir;
 	char *runtime_speechd_dir;
 	char *log_dir;
+	char *module_dir;
 	int log_dir_set;
 	int spawn;
 	int debug;
 	char *debug_destination;
 	char *debug_logfile;
 	int max_history_messages;	/* Maximum of messages in history before they expire */
+	int server_timeout;
+	int server_timeout_set;
 } SpeechdOptions;
 
-struct {
+extern struct SpeechdStatus {
 	int max_uid;		/* The largest assigned uid + 1 */
 	int max_gid;		/* The largest assigned gid + 1 */
 	int max_fd;
 } SpeechdStatus;
 
 /* speak() thread defined in speaking.c */
-pthread_t speak_thread;
-pthread_mutex_t logging_mutex;
-pthread_mutex_t element_free_mutex;
-pthread_mutex_t output_layer_mutex;
-pthread_mutex_t socket_com_mutex;
-
-/* Activity requests for the speaking thread are
- handled with SYSV/IPC semaphore */
-int speaking_sem_id;
+extern pthread_t speak_thread;
+extern pthread_mutex_t logging_mutex;
+extern pthread_mutex_t element_free_mutex;
+extern pthread_mutex_t output_layer_mutex;
+extern pthread_mutex_t socket_com_mutex;
 
 /* Table of all configured (and succesfully loaded) output modules */
 extern GList *output_modules;
 
 /* Table of settings for each active client (=each active socket)*/
-GHashTable *fd_settings;
+extern GHashTable *fd_settings;
 /* Table of default output modules for different languages */
-GHashTable *language_default_modules;
+extern GHashTable *language_default_modules;
 /* Table of relations between client file descriptors and their uids */
-GHashTable *fd_uid;
+extern GHashTable *fd_uid;
 
 /* Speech Dispatcher main priority queue for messages */
-TSpeechDQueue *MessageQueue;
+extern TSpeechDQueue *MessageQueue;
 /* List of messages from paused clients waiting for resume */
-GList *MessagePausedList;
+extern GList *MessagePausedList;
 
 /* List of different entries of client-specific configuration */
-GList *client_specific_settings;
+extern GList *client_specific_settings;
 
 /* Saves the last received priority progress message */
-GList *last_p5_block;
+extern GList *last_p5_block;
 
 /* Global default settings */
-TFDSetElement GlobalFDSet;
-
-/* Variables for socket communication */
-fd_set readfds;
+extern TFDSetElement GlobalFDSet;
 
 /* Inter thread comm pipe */
-int speaking_pipe[2];
+extern int speaking_pipe[2];
 
 /* Managing sockets communication */
-GHashTable *speechd_sockets_status;
+extern GHashTable *speechd_sockets_status;
 typedef struct {
 	int awaiting_data;
 	int inside_block;
@@ -234,13 +232,13 @@ TSpeechDSock *speechd_socket_get_by_fd(int fd);
 /* Debugging */
 void MSG(int level, char *format, ...);
 void MSG2(int level, char *kind, char *format, ...);
-#define FATAL(msg) { fatal_error(); MSG(-1,"Fatal error [%s:%d]:"msg, __FILE__, __LINE__); exit(EXIT_FAILURE); }
-#define DIE(msg) { MSG(0,"Error [%s:%d]:"msg, __FILE__, __LINE__); exit(EXIT_FAILURE); }
+#define FATAL(msg) do { fatal_error(); MSG(-1,"Fatal error [%s:%d]:"msg, __FILE__, __LINE__); exit(EXIT_FAILURE); } while (0)
+#define DIE(msg) do { MSG(0,"Error [%s:%d]:"msg, __FILE__, __LINE__); exit(EXIT_FAILURE); } while (0)
 
-FILE *logfile;
-FILE *custom_logfile;
-char *custom_log_kind;
-FILE *debug_logfile;
+extern FILE *logfile;
+extern FILE *custom_logfile;
+extern char *custom_log_kind;
+extern FILE *debug_logfile;
 
 /* For debugging purposes, does nothing */
 void fatal_error(void);
@@ -249,25 +247,16 @@ void fatal_error(void);
  * returns 1 if yes, 0 otherwise. */
 int isanum(const char *str);
 
-/* Construct a path given a filename and the directory
- where to refer relative paths. filename can be either
- absolute (starting with slash) or relative. */
-char *spd_get_path(char *filename, char *startdir);
-
 /* Functions used in speechd.c only */
 int speechd_connection_new(int server_socket);
 int speechd_connection_destroy(int fd);
-gboolean speechd_client_terminate(gpointer key, gpointer value, gpointer user);
 void speechd_modules_terminate(gpointer data, gpointer user_data);
 void speechd_modules_reload(gpointer data, gpointer user_data);
 void speechd_modules_debug(void);
 void speechd_modules_nodebug(void);
 
-void speechd_reload_dead_modules(int sig);
 void speechd_options_init(void);
 void speechd_init(void);
-void speechd_load_configuration(int sig);
-void speechd_quit(int sig);
 int create_pid_file(void);
 void destroy_pid_file(void);
 
